@@ -1,5 +1,5 @@
 package Hook::WrapSub;
-$Hook::WrapSub::VERSION = '0.06';
+$Hook::WrapSub::VERSION = '0.07';
 use 5.006;
 use strict;
 use warnings;
@@ -11,6 +11,116 @@ our @ISA        = qw/ Exporter /;
 our @EXPORT_OK  = qw/ wrap_subs unwrap_subs /;
 
 
+sub wrap_subs(@) {
+  my( $precall_cr, $postcall_cr );
+  ref($_[0]) and $precall_cr = shift;
+  ref($_[-1]) and $postcall_cr = pop;
+  my @names = @_;
+
+  my( $calling_package ) = caller;
+
+  for my $name ( @names ) {
+
+    my $fullname;
+    my $sr = *{ qualify_to_ref($name,$calling_package) }{CODE};
+    if ( defined $sr ) { 
+      $fullname = qualify($name,$calling_package);
+    }
+    else {
+      warn "Can't find subroutine named '$name'\n";
+      next;
+    }
+
+
+    my $cr = sub {
+      $Hook::WrapSub::UNWRAP and return $sr;
+
+      #
+      # this is a bunch of kludg to make a list of values
+      # that look like a "real" caller() result.
+      #
+
+      my $up = 0;
+      my @args = caller($up);
+      while ( $args[0] =~ /Hook::WrapSub/ ) {
+        $up++;
+        @args = caller($up);
+      }
+      my @vargs = @args; # save temp
+      while ( defined($args[3]) && $args[3] =~ /Hook::WrapSub/ ) {
+        $up++;
+        @args = caller($up);
+      }
+      $vargs[3] = $args[3];
+      # now @vargs looks right.
+
+      local $Hook::WrapSub::name = $fullname;
+      local @Hook::WrapSub::result = ();
+      local @Hook::WrapSub::caller = @vargs;
+      my $wantarray = $Hook::WrapSub::caller[5];
+#
+# try to supply the same calling context to the nested sub:
+#
+
+      unless ( defined $wantarray ) {
+        # void context
+        &$precall_cr  if $precall_cr;
+        &$sr;
+        &$postcall_cr if $postcall_cr;
+        return();
+      }
+
+      unless ( $wantarray ) {
+        # scalar context
+        &$precall_cr  if $precall_cr;
+        $Hook::WrapSub::result[0] = &$sr;
+        &$postcall_cr if $postcall_cr;
+        return $Hook::WrapSub::result[0];
+      }
+
+      # list context
+      &$precall_cr  if $precall_cr;
+      @Hook::WrapSub::result = &$sr;
+      &$postcall_cr if $postcall_cr;
+      return( @Hook::WrapSub::result );
+    };
+
+    no warnings 'redefine';
+    no strict 'refs';
+    *{ $fullname } = $cr;
+  }
+}
+
+sub unwrap_subs(@) {
+  my @names = @_;
+
+  my( $calling_package ) = caller;
+
+  for my $name ( @names ) {
+    my $fullname;
+    my $sr = *{ qualify_to_ref($name,$calling_package) }{CODE};
+    if ( defined $sr ) { 
+      $fullname = qualify($name,$calling_package);
+    }
+    else {
+      warn "Can't find subroutine named '$name'\n";
+      next;
+    }
+    local $Hook::WrapSub::UNWRAP = 1;
+    my $cr = $sr->();
+    if ( defined $cr and $cr =~ /\bCODE\b/ ) {
+      no strict 'refs';
+      no warnings 'redefine';
+      *{ $fullname } = $cr;
+    }
+    else {
+      warn "Subroutine '$fullname' not wrapped!";
+    }
+  }
+}
+
+1;
+
 =head1 NAME
 
 Hook::WrapSub - wrap subs with pre- and post-call hooks
@@ -26,6 +136,10 @@ Hook::WrapSub - wrap subs with pre- and post-call hooks
 
 =head1 DESCRIPTION
 
+This module lets you wrap a function,
+providing one or both of functions that are called just before and just after,
+whenever the wrapped function is called.
+
 There are a number of other modules that provide the same functionality
 as this module, some of them better. Have a look at the list in SEE ALSO,
 below, before you decide which to use.
@@ -180,116 +294,6 @@ number of times.  A "stack" of the wrappings is
 maintained internally.  wrap_subs "pushes" a wrapping,
 and unwrap_subs "pops".
 
-=cut
-
-sub wrap_subs(@) {
-  my( $precall_cr, $postcall_cr );
-  ref($_[0]) and $precall_cr = shift;
-  ref($_[-1]) and $postcall_cr = pop;
-  my @names = @_;
-
-  my( $calling_package ) = caller;
-
-  for my $name ( @names ) {
-
-    my $fullname;
-    my $sr = *{ qualify_to_ref($name,$calling_package) }{CODE};
-    if ( defined $sr ) { 
-      $fullname = qualify($name,$calling_package);
-    }
-    else {
-      warn "Can't find subroutine named '$name'\n";
-      next;
-    }
-
-
-    my $cr = sub {
-      $Hook::WrapSub::UNWRAP and return $sr;
-
-#
-# this is a bunch of kludg to make a list of values
-# that look like a "real" caller() result.
-#
-      my $up = 0;
-      my @args = caller($up);
-      while ( $args[0] =~ /Hook::WrapSub/ ) {
-        $up++;
-        @args = caller($up);
-      }
-      my @vargs = @args; # save temp
-      while ( defined($args[3]) && $args[3] =~ /Hook::WrapSub/ ) {
-        $up++;
-        @args = caller($up);
-      }
-      $vargs[3] = $args[3];
-      # now @vargs looks right.
-
-      local $Hook::WrapSub::name = $fullname;
-      local @Hook::WrapSub::result = ();
-      local @Hook::WrapSub::caller = @vargs;
-      my $wantarray = $Hook::WrapSub::caller[5];
-#
-# try to supply the same calling context to the nested sub:
-#
-
-      unless ( defined $wantarray ) {
-        # void context
-        &$precall_cr  if $precall_cr;
-        &$sr;
-        &$postcall_cr if $postcall_cr;
-        return();
-      }
-
-      unless ( $wantarray ) {
-        # scalar context
-        &$precall_cr  if $precall_cr;
-        $Hook::WrapSub::result[0] = &$sr;
-        &$postcall_cr if $postcall_cr;
-        return $Hook::WrapSub::result[0];
-      }
-
-      # list context
-      &$precall_cr  if $precall_cr;
-      @Hook::WrapSub::result = &$sr;
-      &$postcall_cr if $postcall_cr;
-      return( @Hook::WrapSub::result );
-    };
-
-    no warnings 'redefine';
-    no strict 'refs';
-    *{ $fullname } = $cr;
-  }
-}
-
-sub unwrap_subs(@) {
-  my @names = @_;
-
-  my( $calling_package ) = caller;
-
-  for my $name ( @names ) {
-    my $fullname;
-    my $sr = *{ qualify_to_ref($name,$calling_package) }{CODE};
-    if ( defined $sr ) { 
-      $fullname = qualify($name,$calling_package);
-    }
-    else {
-      warn "Can't find subroutine named '$name'\n";
-      next;
-    }
-    local $Hook::WrapSub::UNWRAP = 1;
-    my $cr = $sr->();
-    if ( defined $cr and $cr =~ /\bCODE\b/ ) {
-      no strict 'refs';
-      no warnings 'redefine';
-      *{ $fullname } = $cr;
-    }
-    else {
-      warn "Subroutine '$fullname' not wrapped!";
-    }
-  }
-}
-
-1;
 
 =head1 SEE ALSO
 
@@ -344,7 +348,9 @@ L<https://github.com/neilb/Hook-WrapSub>
 
 =head1 AUTHOR
 
-jdporter@min.net (John Porter)
+This module was written by John Porter E<lt>jdporter@min.netE<gt>
+
+It is now being maintained by Neil Bowers.
 
 =head1 COPYRIGHT
 
